==> Paws-0.36.tar.gz: Paws-0.36/lib/Paws/SSM/UpdateDocumentDefaultVersion.pm <==

package Paws::SSM::UpdateDocumentDefaultVersion;
  use Moose;
  has DocumentVersion => (is => 'ro', isa => 'Str', required => 1);
  has Name => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'UpdateDocumentDefaultVersion');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::SSM::UpdateDocumentDefaultVersionResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SSM::UpdateDocumentDefaultVersion - Arguments for method UpdateDocumentDefaultVersion on Paws::SSM

=head1 DESCRIPTION

This class represents the parameters used for calling the method UpdateDocumentDefaultVersion on the 
Amazon Simple Systems Manager (SSM) service. Use the attributes of this class
as arguments to method UpdateDocumentDefaultVersion.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to UpdateDocumentDefaultVersion.

As an example:

  $service_obj->UpdateDocumentDefaultVersion(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> DocumentVersion => Str

The version of a custom document that you want to set as the default
version.



=head2 B<REQUIRED> Name => Str

The name of a custom document that you want to set as the default
version.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method UpdateDocumentDefaultVersion in L<Paws::SSM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.45.tar.gz: Paws-0.45/lib/Paws/SSM/UpdateDocumentDefaultVersion.pm <==

package Paws::SSM::UpdateDocumentDefaultVersion;
  use Moose;
  has DocumentVersion => (is => 'ro', isa => 'Str', required => 1);
  has Name => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'UpdateDocumentDefaultVersion');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::SSM::UpdateDocumentDefaultVersionResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SSM::UpdateDocumentDefaultVersion - Arguments for method UpdateDocumentDefaultVersion on L<Paws::SSM>

=head1 DESCRIPTION

This class represents the parameters used for calling the method UpdateDocumentDefaultVersion on the
L<Amazon Simple Systems Manager (SSM)|Paws::SSM> service. Use the attributes of this class
as arguments to method UpdateDocumentDefaultVersion.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to UpdateDocumentDefaultVersion.

=head1 SYNOPSIS

    my $ssm = Paws->service('SSM');
    my $UpdateDocumentDefaultVersionResult = $ssm->UpdateDocumentDefaultVersion(
      DocumentVersion => 'MyDocumentVersionNumber',
      Name            => 'MyDocumentName',

    );

    # Results:
    my $Description = $UpdateDocumentDefaultVersionResult->Description;

    # Returns a L<Paws::SSM::UpdateDocumentDefaultVersionResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/ssm/UpdateDocumentDefaultVersion>

=head1 ATTRIBUTES


=head2 B<REQUIRED> DocumentVersion => Str

The version of a custom document that you want to set as the default
version.



=head2 B<REQUIRED> Name => Str

The name of a custom document that you want to set as the default
version.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method UpdateDocumentDefaultVersion in L<Paws::SSM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
